@@ -4,6 +4,7 @@ import pandas as pd
 import transformers
 from sklearn.metrics import precision_recall_fscore_support
 from sklearn.metrics import accuracy_score
+from sklearn.metrics import balanced_accuracy_score
 
 from BERT_STEM.Encode import *
 from BERT_STEM.TrainBERT4PT import *
@@ -121,8 +122,9 @@ class BertSTEMForTextClassification:
         preds = pred.predictions.argmax(-1)
         precision, recall, f1, _ = precision_recall_fscore_support(labels, preds, average='weighted')
         acc = accuracy_score(labels, preds)
-
+        bacc = balanced_accuracy_score(labels, preds)
         return {
+            'bacc': bacc
             'accuracy': acc,
             'f1': f1,
             'precision': precision,
@@ -130,7 +132,8 @@ class BertSTEMForTextClassification:
         }
 
 
-    def _train(self, inputs_train, inputs_val, num_train_epochs=3, learning_rate=1e-5, load_best_model_at_end=True, early_stopping_patience=5):
+    def _train(self, inputs_train, inputs_val, num_train_epochs=3, learning_rate=1e-5,
+               load_best_model_at_end=True, early_stopping_patience=5, metric_for_best_model="bacc"):
 
         dataset_train = CorpusDataset(inputs_train)
         dataset_val = CorpusDataset(inputs_val)
@@ -146,7 +149,8 @@ class BertSTEMForTextClassification:
                                                learning_rate = learning_rate,
                                                load_best_model_at_end=load_best_model_at_end,
                                                evaluation_strategy="epoch",
-                                               save_strategy = "epoch")
+                                               save_strategy = "epoch",
+                                               metric_for_best_model = metric_for_best_model)
         
         early_stopping = transformers.EarlyStoppingCallback(early_stopping_patience=5)
         
